@@ -19,7 +19,6 @@ import copy
 import io
 import json
 import logging
-import re
 import zipfile
 
 import pkg_resources
@@ -219,6 +218,11 @@ class ListField(Field):
         return getattr(self, key)
 
 
+class LinksField(CompositeField):
+    """Reference to linked resources."""
+    oem_vendors = Field('Oem', adapter=list)
+
+
 class DictionaryField(Field):
     """Base class for fields consisting of dictionary of several sub-fields."""
 
@@ -326,7 +330,7 @@ class MappedListField(Field):
 class MessageListField(ListField):
     """List of messages with details of settings update status"""
 
-    message_id = Field('MessageId')
+    message_id = Field('MessageId', required=True)
     """The key for this message which can be used
     to look up the message in a message registry
     """
@@ -484,9 +488,11 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
     redfish_version = None
     """The Redfish version"""
 
-    oem_vendors = Field('Oem', adapter=list)
+    _oem_vendors = Field('Oem', adapter=list)
     """The list of OEM extension names for this resource."""
 
+    links = LinksField('Links')
+
     def __init__(self,
                  connector,
                  path='',
@@ -564,35 +570,6 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
 
         return settings
 
-    def _get_etag(self):
-        """Returns the ETag of the HTTP request if any was specified.
-
-        :returns ETag or None
-        """
-        pattern = re.compile(r'^(W\/)?("\w*")$')
-        match = pattern.match(self._get_headers().get('ETag', ''))
-        if match:
-            return match.group(2)
-        return None
-
-    def _get_headers(self):
-        """Returns the HTTP headers of the request for the resource.
-
-        :returns: dict of HTTP headers
-        """
-        return self._reader.get_data()._headers
-
-    def _allow_patch(self):
-        """Returns if the resource supports the PATCH HTTP method.
-
-        If the resource supports the PATCH HTTP method for updates,
-        it will return it in the Allow HTTP header.
-        :returns: Boolean flag if PATCH is supported or not
-        """
-        allow_header = self._get_headers().get('Allow', '')
-        methods = set([h.strip().upper() for h in allow_header.split(',')])
-        return "PATCH" in methods
-
     def refresh(self, force=True, json_doc=None):
         """Refresh the resource
 
@@ -668,6 +645,12 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
         if force_refresh:
             self.refresh()
 
+    @property
+    def oem_vendors(self):
+        return list(
+            set((self._oem_vendors or []) + (self.links.oem_vendors or []))
+        )
+
     @property
     def json(self):
         return self._json
